# -*- coding: iso-8859-1 -*-
"""
    MoinMoin ubuntu theme

    @copyright: (c) 2003-2004 by Nir Soffer, Thomas Waldmann
		(c) Henrik Omma / Heather Stern (ubuntu theme)
		(c) 2008 by Matthew East (new ubuntu theme)

    @license: GNU GPL, see COPYING for details.

"""

from MoinMoin.theme import ThemeBase
from MoinMoin import wikiutil
from MoinMoin.Page import Page


class Theme(ThemeBase):

    name = 'ubuntunew'

    def header(self, d, **kw):
        """ Assemble wiki header
        
        @param d: parameter dictionary
        @rtype: unicode
        @return: page header html
        """
        request = self.request

        html = [
            # Pre header custom html
            self.emit_custom_html(self.cfg.page_header1),
            
            # Header
            u'<div id="round" class="roundme">',
            u'<img id="topcap" alt="" src="/htdocs/ubuntunew/img/cap-top.png">',
            u'<div id="layout" class="container clear-block">',
            u'<div id="header">',
            u'<div id="logo-floater">',
            u'<h1><a href="http://help.ubuntu.com" title="Ubuntu Documentation"><img alt="Ubuntu" id="logo" src="/htdocs/ubuntunew/img/logo.png" /><span>Ubuntu</span></a></h1>',
            u'</div>',
	    self.loginbar(d),
            self.searchform(d),
            u'</div> <!--header-->',
            self.msg(d),
           
            # Post header custom html (not recommended)
            self.emit_custom_html(self.cfg.page_header2),'<!--1-->',
            
            # Start of page
            self.startPage(),'<!--2-->',
            self.title(d),'<!--3-->',
        ]
        return u'\n'.join(html)

    editorheader = header

    def title(self, d, **kw):
        """ Assemble the title (now using breadcrumbs)
        
        @param d: parameter dictionary
        @rtype: string
        @return: title html
        """
        _ = self.request.getText
        content = []

        if (d['title_text'] == d['page'].split_title()) and (not d['page'].pi.has_key('title')): # just showing a page, no action
            curpage = ''
            segments = d['page_name'].split('/') # was: title_text
            for s in segments[:-1]:
                curpage += s
                content.append("<li>%s</li>" % Page(self.request, curpage).link_to(self.request, s))
                curpage += '/'
            link_text = segments[-1]
            link_title = _('Click to do a full-text search for this title', formatted=False)
            link_query = {
                'action': 'fullsearch',
                'value': 'linkto:"%s"' % d['page_name'],
                'context': '180',
            }
            # we dont use d['title_link'] any more, but make it ourselves:
            link = d['page'].link_to(self.request, link_text, querystr=link_query, title=link_title, css_class='backlink', rel='nofollow')
            content.append(('<li>%s</li>') % link)
        else:
            content.append('<li>%s</li>' % wikiutil.escape(d['title_text']))

        html = '''
<ul id="pagelocation">
%s
</ul>
''' % "".join(content)
        return html

    def editbar(self, d):
        """ Assemble the page edit bar.

        Display on existing page. Replace iconbar, showtext, edit text,
        refresh cache and available actions.
        
        @param d: parameter dictionary
        @rtype: unicode
        @return: iconbar html
        """
        page = d['page']       
        if not self.shouldShowEditbar(page):
            return ''

        # Use cached editbar if possible.
        cacheKey = 'editbar'
        cached = self._cache.get(cacheKey)
        if cached:
            return cached

        # Make new edit bar
        request = self.request
        _ = self.request.getText
        link = wikiutil.link_tag
        quotedname = wikiutil.quoteWikinameURL(page.page_name)
        links = []
        add = links.append
                
        # Page actions
        if page.isWritable() and request.user.valid and request.user.may.write(page.page_name):
            add(self.editorLink(page))
	    add(self.infoLink(page))
            add(self.subscribeLink(page))
	    add(self.attachmentsLink(page))
            add(self.actionsMenu(page))
            # Add link to RecentChanges
            changesPage = wikiutil.getLocalizedPage(request, 'RecentChanges')
            title = changesPage.split_title(request)
            add(changesPage.link_to(request, text=title))
            # Add link to WikiGuide
            guidePage = wikiutil.getLocalizedPage(request, 'WikiGuide')
            title = guidePage.split_title(request)
            add(guidePage.link_to(request, text=title))

        # Add username/homepage link for registered users. We don't care
        # if it exists, the user can create it.
        if request.user.valid and request.user.name:
            interwiki = wikiutil.getInterwikiHomePage(request)
            name = request.user.name
            aliasname = request.user.aliasname
            if not aliasname:
                aliasname = name
            title = "%s @ %s" % (aliasname, interwiki[0])
            # link to (interwiki) user homepage
            homelink = (request.formatter.interwikilink(1, title=title, id="userhome", generated=True, *interwiki) +
                        request.formatter.text(name) +
                        request.formatter.interwikilink(0, title=title, id="userhome", *interwiki))
            add(homelink)
            # link to preferences page
            add(d['page'].link_to(request, text=_('Preferences', formatted=False),
                                               querystr={'action': 'userprefs'}, id='userprefs', rel='nofollow'))
	# logout link
        if request.cfg.show_login:
            if request.user.valid:
                add(d['page'].link_to(request, text=_('Logout', formatted=False),
                                                   querystr={'action': 'logout', 'logout': 'logout'}, id='logout', rel='nofollow'))
            else:
                pass
            
        elif not request.user.valid:
            pass 
        else:
            add(_('Immutable Page', formatted=False))             

        # Format
        items = '\n'.join(['<li>%s</li>' % item for item in links if item != ''])
        html = u'<ul class="editbar">\n%s\n</ul>\n' % items
        
        # cache for next call
        self._cache[cacheKey] = html

        return html

    def infoLink(self, page):

	# Instead of "Info", Link text should read "Page History" 
        """ Return link to page information """
        _ = self.request.getText
        return page.link_to(self.request,
                            text=_('Page History', formatted=False),
                            querystr={'action': 'info'}, css_class='nbinfo', rel='nofollow')


    def footer(self, d, **keywords):
        """ Assemble wiki footer
        
        @param d: parameter dictionary
        @keyword ...:...
        @rtype: unicode
        @return: page footer html
        """
        page = d['page']
        html = [
            # End of page
            self.pageinfo(page),
	    self.pagelinks(d),
            self.endPage(),
            
            # Pre footer custom html (not recommended!)
            self.emit_custom_html(self.cfg.page_footer1),
            
            # Footer
            u'<div id="footer">',
	    u'<hr width="550px">',
            self.footerlinks(),
            self.showversion(d, **keywords),
            u'</div> <!-- footer -->',
            u'</div> <!-- layout -->',
	    u'<img id="bottomcap" alt="" src="/htdocs/ubuntunew/img/cap-bottom.png">',
            u'</div> <!-- round -->',
            # Post footer custom html
            self.emit_custom_html(self.cfg.page_footer2),
            ]
	# For logged in users, show editbar
        request = self.request
        if request.user.valid:
            html.extend([
                self.editbar(d),
            ])
        return u'\n'.join(html)

    def pagelinks(self, d):

        page = d['page']       
        request = self.request
        _ = self.request.getText
        link = wikiutil.link_tag
        quotedname = wikiutil.quoteWikinameURL(page.page_name)
        links = []
        add = links.append

        # Parent page
        parent = page.getParentPage()
        if parent:
            add(parent.link_to(request, _("Parent Page", formatted=False))) 
        add(self.infoLink(page))

        # Format
        items = '\n'.join(['<li>%s</li>' % item for item in links if item != ''])
        html = u'<ul class="pagelinks">\n%s\n</ul>\n' % items
        
        return html


    def footerlinks(self):
        """ Copyright notices 

        Nice and boring compared to the other stuff. 
        
        @rtype: unicode
        @return: extra footer html
        """

        html = u'''
  <div id="ubuntulinks">
	<p>
	      The material on this wiki is available under a free license, see <a href="https://help.ubuntu.com/community/License">Copyright / License</a> for details<br /><b>You</b> can contribute to this wiki, see <a href="https://help.ubuntu.com/community/WikiGuide">Wiki Guide</a> for details
	</p><br>
  </div>
<script src="https://ssl.google-analytics.com/urchin.js" type="text/javascript">
</script>
<script type="text/javascript">
_uacct = "UA-1018242-7";
urchinTracker();
__utmSetVar('UbuntuWiki');
</script>
'''
        return html
        return u''

    def loginbar(self, d):
        """ If not logged in, offer to do so
        
        @param d: parameter dictionary
        @rtype: unicode
        @return: username html
        """
        request = self.request
        _ = request.getText

        loginbarlinks = []
        # Add username/homepage link for registered users. We don't care
        # if it exists, the user can create it.
        if request.user.valid:
	    pass
        else:
            loginbarlinks.append(d['page'].link_to(request, text=_("Login to Edit", formatted=False),
                                               querystr={'action': 'login'}, id='login', rel='nofollow'))

        loginbarlinks = [u'<li>%s</li>' % link for link in loginbarlinks]
        html = u'<ul id="loginbar">%s</ul>' % ''.join(loginbarlinks)
        return html

        
def execute(request):
    """
    Generate and return a theme object
        
    @param request: the request object
    @rtype: MoinTheme
    @return: Theme object
    """
    return Theme(request)

